In this directory you can find examples using the "low-level" interfaces of the FEM module of welib.
Higher-level interfaces are found in the module `fast` to generate FEM models from typical OpenFAST files.


- `Graph_CreateSimpleGraph.py`: Examples to use the Graph class and generate a JSON file that can be used with [viz3danim[(https://github.com/ebranlard/viz3danim). 

- `Beam_ModeShapes_Tower.py`: Example to compute mode shapes of a tower using a beam FEM model.  

- `Beam_ModeShapes_UniformBeamFrame3d.py: Use a finite element method (FEM) formulation using frame elements to compute the mode shapes of a uniform beam cantilevered with and without top mass.
